@@ -28,6 +28,7 @@ __all__ = (
     "CodeReviewSummaryTypeDef",
     "CodeReviewTypeDef",
     "CommitDiffSourceCodeTypeTypeDef",
+    "KMSKeyDetailsTypeDef",
     "MetricsSummaryTypeDef",
     "MetricsTypeDef",
     "RecommendationFeedbackSummaryTypeDef",
@@ -100,6 +101,12 @@ CommitDiffSourceCodeTypeTypeDef = TypedDict(
     "CommitDiffSourceCodeTypeTypeDef", {"SourceCommit": str, "DestinationCommit": str}, total=False
 )
 
+KMSKeyDetailsTypeDef = TypedDict(
+    "KMSKeyDetailsTypeDef",
+    {"KMSKeyId": str, "EncryptionOption": Literal["AWS_OWNED_CMK", "CUSTOMER_MANAGED_CMK"]},
+    total=False,
+)
+
 MetricsSummaryTypeDef = TypedDict(
     "MetricsSummaryTypeDef", {"MeteredLinesOfCodeCount": int, "FindingsCount": int}, total=False
 )
@@ -171,6 +178,7 @@ RepositoryAssociationTypeDef = TypedDict(
         "StateReason": str,
         "LastUpdatedTimeStamp": datetime,
         "CreatedTimeStamp": datetime,
+        "KMSKeyDetails": "KMSKeyDetailsTypeDef",
     },
     total=False,
 )
